==> java-sdk-4.2.0-sources.jar: com/baidu/aip/ocr/OcrConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.ocr;

public class OcrConsts {

    static final String GENERAL_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_basic";

    static final String ACCURATE_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";

    static final String GENERAL = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";

    static final String ACCURATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate";

    static final String GENERAL_ENHANCED = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_enhanced";

    static final String WEB_IMAGE = "https://aip.baidubce.com/rest/2.0/ocr/v1/webimage";

    static final String IDCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/idcard";

    static final String BANKCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/bankcard";

    static final String DRIVING_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/driving_license";

    static final String VEHICLE_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_license";

    static final String LICENSE_PLATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/license_plate";

    static final String BUSINESS_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_license";

    static final String RECEIPT = "https://aip.baidubce.com/rest/2.0/ocr/v1/receipt";

    static final String CUSTOM = "https://aip.baidubce.com/rest/2.0/solution/v1/iocr/recognise";

    static final String FORM = "https://aip.baidubce.com/rest/2.0/ocr/v1/form";

    static final String TABLE_RECOGNIZE = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/request";

    static final String TABLE_RESULT_GET = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/get_request_result";

    static final int ASYNC_TASK_STATUS_FINISHED = 3;
}

==> java-sdk-4.4.1-sources.jar: com/baidu/aip/ocr/OcrConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.ocr;

public class OcrConsts {

    static final String GENERAL_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_basic";

    static final String ACCURATE_BASIC = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate_basic";

    static final String GENERAL = "https://aip.baidubce.com/rest/2.0/ocr/v1/general";

    static final String ACCURATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/accurate";

    static final String GENERAL_ENHANCED = "https://aip.baidubce.com/rest/2.0/ocr/v1/general_enhanced";

    static final String WEB_IMAGE = "https://aip.baidubce.com/rest/2.0/ocr/v1/webimage";

    static final String IDCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/idcard";

    static final String BANKCARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/bankcard";

    static final String DRIVING_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/driving_license";

    static final String VEHICLE_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vehicle_license";

    static final String LICENSE_PLATE = "https://aip.baidubce.com/rest/2.0/ocr/v1/license_plate";

    static final String BUSINESS_LICENSE = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_license";

    static final String RECEIPT = "https://aip.baidubce.com/rest/2.0/ocr/v1/receipt";

    static final String FORM = "https://aip.baidubce.com/rest/2.0/ocr/v1/form";

    static final String TABLE_RECOGNIZE = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/request";

    static final String TABLE_RESULT_GET = "https://aip.baidubce.com/rest/2.0/solution/v1/form_ocr/get_request_result";

    static final String VAT_INVOICE = "https://aip.baidubce.com/rest/2.0/ocr/v1/vat_invoice";

    static final String QRCODE = "https://aip.baidubce.com/rest/2.0/ocr/v1/qrcode";

    static final String NUMBERS = "https://aip.baidubce.com/rest/2.0/ocr/v1/numbers";

    static final String LOTTERY = "https://aip.baidubce.com/rest/2.0/ocr/v1/lottery";

    static final String PASSPORT = "https://aip.baidubce.com/rest/2.0/ocr/v1/passport";

    static final String BUSINESS_CARD = "https://aip.baidubce.com/rest/2.0/ocr/v1/business_card";

    static final String HANDWRITING = "https://aip.baidubce.com/rest/2.0/ocr/v1/handwriting";

    static final String CUSTOM = "https://aip.baidubce.com/rest/2.0/solution/v1/iocr/recognise";

    static final int ASYNC_TASK_STATUS_FINISHED = 3;
}
